### Pre Reqs

- Python 3+ installed
- Pip3 installed
- VS Code Installed

### Follow these Instuctions 

*Recommended Method*
[https://code.visualstudio.com/docs/datascience/jupyter-notebooks](Jupyter Notebooks in VS Code)